@@ -15,6 +15,7 @@ from pyadvincekit.core.excel_generator import (
     SQLGenerator, ORMGenerator, PydanticGenerator, DatabaseDesign
 )
 from pyadvincekit.core.api_generator import APIServiceGenerator
+from pyadvincekit.docs.decorators import api_category, api_doc, api_example
 
 logger = get_logger(__name__)
 
@@ -727,6 +728,53 @@ class DatabaseCodeGenerator:
 
 
 # 便捷函数
+@api_category("工具类使用", "Excel代码生成")
+@api_doc(
+    title="Excel数据库代码生成",
+    description="从Excel文件自动生成数据库SQL、ORM模型和Pydantic Schema",
+    params={
+        "excel_file": "Excel数据库设计文件路径",
+        "output_dir": "代码输出目录（默认：generated）", 
+        "generate_sql": "是否生成SQL文件（默认：True）",
+        "generate_orm": "是否生成ORM模型（默认：True）",
+        "generate_pydantic": "是否生成Pydantic Schema（默认：True）",
+        "generate_api": "是否生成API接口（默认：False）",
+        "generate_service": "是否生成Service层（默认：False）",
+        "database_name": "数据库名称（可选）",
+        "add_standard_fields": "是否自动添加标准字段（id、created_at、updated_at）"
+    },
+    returns="Dict[str, Any]: 生成文件信息和统计数据",
+    version="2.0.0"
+)
+@api_example('''
+from pyadvincekit import generate_database_code
+
+# 基础用法：从Excel生成基础代码
+result = generate_database_code(
+    excel_file="./database_design.xlsx",
+    output_dir="./generated"
+)
+print(f"生成了 {len(result['orm_files'])} 个ORM文件")
+
+# 高级用法：生成完整项目结构
+result = generate_database_code(
+    excel_file="./database_design.xlsx", 
+    output_dir="./my_project",
+    generate_api=True,
+    generate_service=True,
+    separate_files=True,
+    add_standard_fields=True
+)
+print(f"完整项目生成：ORM({len(result['orm_files'])}), API({len(result['api_files'])})")
+
+# 定制输出：分目录生成
+result = generate_database_code(
+    excel_file="./database_design.xlsx",
+    orm_output_dir="app/models",
+    schema_output_dir="app/schemas", 
+    sql_output_dir="database/sql"
+)
+''', description="Excel代码生成的多种使用方式")
 def generate_database_code(
     excel_file: str,
     output_dir: str = "generated",
@@ -737,10 +785,10 @@ def generate_database_code(
     generate_service: bool = False,
     database_name: Optional[str] = None,
     # 新增参数：支持分目录和分文件生成
-    orm_output_dir: Optional[str] = None,
-    schema_output_dir: Optional[str] = None,
-    sql_output_dir: Optional[str] = None,
-    separate_files: bool = False,
+    orm_output_dir: Optional[str] = "models",
+    schema_output_dir: Optional[str] = "schemas",
+    sql_output_dir: Optional[str] = "sql",
+    separate_files: bool = True,
     auto_init_files: bool = True,
     # 🔥 新增参数：是否自动添加标准字段
     add_standard_fields: bool = True
